# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [0.1.0] - 2025-01-20

### Added
- Initial release of MCP Screen Operation Server
- Cross-platform support for Linux, Windows, and macOS
- Screen capture operations (individual monitors and all screens)
- Window management and capture
- Mouse automation (move, click, drag, scroll)
- Keyboard automation (type, press, hotkeys)
- Multiple transport protocols (STDIO, SSE, Streamable HTTP)
- Platform-specific dependency management
- FastMCP integration for modern MCP server implementation
